setwd("~/Rocnikovka/Working_directory")


install.packages("haven")
install.packages("data.table")
install.packages("dplyr")
install.packages("ggplot2")
install.packages("hrbrthemes")
install.packages("plm")
install.packages("ggpubr")
install.packages("gravity")
install.packages("foreign")
install.packages("stargazer")
install.packages("lfe")
install.packages("lmtest")
install.packages("MASS")

library(haven)
library(data.table)
library(dplyr)
library(ggplot2)
library(hrbrthemes)
library(plm)
library(ggpubr)
library(gravity)
library(foreign)
library(stargazer)
library(lfe)
library(lmtest)
library(MASS)
# install packages


gravity_dataset <- read_dta("~/Rocnikovka/data/Gravity_data/gravdata_cepii/gravdata.dta")
year_origin_destination_hs02_4 <- read.delim("~/Rocnikovka/data/year_origin_destination_hs02_4.tsv/year_origin_destination_hs02_4.tsv")
# read it into a useful format (can't open .tsv bc it is too large)


data_table_year_origin_destination_hs02_4 <- data.table(year_origin_destination_hs02_4.RData)
# use that package to transform the huge originally .tsv table into a data.table

data_table_year_origin_destination_hs02_4$export_val <- as.numeric(data_table_year_origin_destination_hs02_4$export_val)
data_table_year_origin_destination_hs02_4$import_val <- as.numeric(data_table_year_origin_destination_hs02_4$import_val)
# transform the columns from factors into characters so that I can change null to zero

data_table_year_origin_destination_hs02_4[is.na(data_table_year_origin_destination_hs02_4)] <- 0
# in that table change every null variable to a '0'
# need to do this transformation in order to be albe to merge the rows of the data table since it is classified by products which I don't need

transformed_trade <- data_table_year_origin_destination_hs02_4 %>%
group_by(year, origin, dest) %>%
summarise(total_import = sum(import_val), total_export = sum(export_val))
# the import and export values if the year, origin and destination is the same since I don't need 50 rows by product for each country pair

gravity_dataset$iso3_d <- tolower(gravity_dataset$iso3_d)
gravity_dataset$iso3_o <- tolower(gravity_dataset$iso3_o)
# change the country abbrevations to lowercase to match the ones in the trade data frame

names(transformed_trade) <- c("year", "iso3_o", "iso3_d", "total_import", "total_export")
# change the names of the columns so that they match the ones from the gravity dataset

total_dataset <- merge(gravity_dataset, transformed_trade, by = c("year", "iso3_d", "iso3_o"))
# merge the two datasets based on year, country of origin and country of destination


total_dataset$total_import[total_dataset$total_import == 0] <- 1
total_dataset$total_export[total_dataset$total_export == 0] <- 1
# transform all zeros in import and export to 1 (doesn't really make a difference since the numbers are so large, but makes it possible to run a log-linear model bc ln(0) = -inf)


dataset_2013_above <- subset(total_dataset, total_dataset$year >= 2013)


dummy_2014 <- as.numeric(dataset_2013_above$year == 2014)
dummy_2015 <- as.numeric(dataset_2013_above$year == 2015)
# generate dummy variables for each year - 1


dataset_2013_above$dummy2014 <- dummy_2014
dataset_2013_above$dummy2015 <- dummy_2015
# create new columns in my dataset for the year dummy variables


total_dataset$trade_flow <- total_dataset$total_export + total_dataset$total_import
# create a single column that is the sum of the export and import


# SUBSET THE DATASET BY COUNTRIES WHOSE ORIGIN AND DESTINATION IS A PART OF THE BRI
#     dataset_2013_above_bothin_step1b <- subset(dataset_2013_above, dataset_2013_above$iso3_o =="nam"|dataset_2013_above$iso3_o =="npl"|dataset_2013_above$iso3_o =="nzl"|dataset_2013_above$iso3_o =="nga"|dataset_2013_above$iso3_o =="niu"|dataset_2013_above$iso3_o =="mkd"|dataset_2013_above$iso3_o =="omn"|dataset_2013_above$iso3_o =="pak"|dataset_2013_above$iso3_o =="pse"|dataset_2013_above$iso3_o =="pan"|dataset_2013_above$iso3_o =="png"|dataset_2013_above$iso3_o =="per"|dataset_2013_above$iso3_o =="phl"|dataset_2013_above$iso3_o =="pol"|dataset_2013_above$iso3_o =="prt"|dataset_2013_above$iso3_o =="qat"|dataset_2013_above$iso3_o =="rou"|dataset_2013_above$iso3_o =="rus"|dataset_2013_above$iso3_o =="rwa"|dataset_2013_above$iso3_o =="wsm"|dataset_2013_above$iso3_o =="sau"|dataset_2013_above$iso3_o =="sen"|dataset_2013_above$iso3_o =="srb"|dataset_2013_above$iso3_o =="spa"|dataset_2013_above$iso3_o =="syc"|dataset_2013_above$iso3_o =="sle"|dataset_2013_above$iso3_o =="sgp"|dataset_2013_above$iso3_o =="svk"|dataset_2013_above$iso3_o =="svn"|dataset_2013_above$iso3_o =="som"|dataset_2013_above$iso3_o =="zaf"|dataset_2013_above$iso3_o =="ssd"|dataset_2013_above$iso3_o =="lka"|dataset_2013_above$iso3_o =="sdn"|dataset_2013_above$iso3_o =="sur"|dataset_2013_above$iso3_o =="syr"|dataset_2013_above$iso3_o =="tjk"|dataset_2013_above$iso3_o =="tza"|dataset_2013_above$iso3_o =="tha"|dataset_2013_above$iso3_o =="tls"|dataset_2013_above$iso3_o =="tgo"|dataset_2013_above$iso3_o =="ton"|dataset_2013_above$iso3_o =="tto"|dataset_2013_above$iso3_o =="tun"|dataset_2013_above$iso3_o =="tur"|dataset_2013_above$iso3_o =="tkm"|dataset_2013_above$iso3_o =="uga"|dataset_2013_above$iso3_o =="ukr"|dataset_2013_above$iso3_o =="are"|dataset_2013_above$iso3_o =="ury"|dataset_2013_above$iso3_o =="uzb"|dataset_2013_above$iso3_o =="vut"|dataset_2013_above$iso3_o =="ven"|dataset_2013_above$iso3_o =="vnm"|dataset_2013_above$iso3_o =="yem"|dataset_2013_above$iso3_o =="zmb"|dataset_2013_above$iso3_o =="zwe")
#     dataset_2013_above_bothin_step1 <- subset(dataset_2013_above, dataset_2013_above $iso3_o == "chn"|dataset_2013_above$iso3_o =="afg"|dataset_2013_above$iso3_o =="alb"|dataset_2013_above$iso3_o =="dza"|dataset_2013_above$iso3_o =="ago"|dataset_2013_above$iso3_o =="atg"|dataset_2013_above$iso3_o =="arm"|dataset_2013_above$iso3_o =="aut"|dataset_2013_above$iso3_o =="aze"|dataset_2013_above$iso3_o =="bhr"|dataset_2013_above$iso3_o =="bgd"|dataset_2013_above$iso3_o =="brb"|dataset_2013_above$iso3_o =="blr"|dataset_2013_above$iso3_o =="btn"|dataset_2013_above$iso3_o =="bhu"|dataset_2013_above$iso3_o =="bol"|dataset_2013_above$iso3_o =="bih"|dataset_2013_above$iso3_o =="brn"|dataset_2013_above$iso3_o =="bgr"|dataset_2013_above$iso3_o =="bdi"|dataset_2013_above$iso3_o =="khm"|dataset_2013_above$iso3_o =="cmr"|dataset_2013_above$iso3_o =="cpv"|dataset_2013_above$iso3_o =="tcd"|dataset_2013_above$iso3_o =="chl"|dataset_2013_above$iso3_o =="cog"|dataset_2013_above$iso3_o =="cok"|dataset_2013_above$iso3_o =="crc"|dataset_2013_above$iso3_o =="cri"|dataset_2013_above$iso3_o =="civ"|dataset_2013_above$iso3_o =="hrv"|dataset_2013_above$iso3_o =="cub"|dataset_2013_above$iso3_o =="cyp"|dataset_2013_above$iso3_o =="cze"|dataset_2013_above$iso3_o =="dji"|dataset_2013_above$iso3_o =="dma"|dataset_2013_above$iso3_o =="dom"|dataset_2013_above$iso3_o =="ecu"|dataset_2013_above$iso3_o =="egy"|dataset_2013_above$iso3_o =="slv"|dataset_2013_above$iso3_o =="gnq"|dataset_2013_above$iso3_o =="est"|dataset_2013_above$iso3_o =="eth"|dataset_2013_above$iso3_o =="fji"|dataset_2013_above$iso3_o =="gab"|dataset_2013_above$iso3_o =="gmb"|dataset_2013_above$iso3_o =="geo"|dataset_2013_above$iso3_o =="gha"|dataset_2013_above$iso3_o =="grc"|dataset_2013_above$iso3_o =="grd"|dataset_2013_above$iso3_o =="gin"|dataset_2013_above$iso3_o =="guy"|dataset_2013_above$iso3_o =="hun"|dataset_2013_above$iso3_o =="idn"|dataset_2013_above$iso3_o =="irn"|dataset_2013_above$iso3_o =="irq"|dataset_2013_above$iso3_o =="isr"|dataset_2013_above$iso3_o =="ita"|dataset_2013_above$iso3_o =="jam"|dataset_2013_above$iso3_o =="jor"|dataset_2013_above$iso3_o =="kaz"|dataset_2013_above$iso3_o =="kgz"|dataset_2013_above$iso3_o =="ken"|dataset_2013_above$iso3_o =="kor"|dataset_2013_above$iso3_o =="kwt"|dataset_2013_above$iso3_o =="lao"|dataset_2013_above$iso3_o =="lva"|dataset_2013_above$iso3_o =="lbn"|dataset_2013_above$iso3_o =="lbr"|dataset_2013_above$iso3_o =="lby"|dataset_2013_above$iso3_o =="ltu"|dataset_2013_above$iso3_o =="lux"|dataset_2013_above$iso3_o =="mdg"|dataset_2013_above$iso3_o =="mys"|dataset_2013_above$iso3_o =="mdv"|dataset_2013_above$iso3_o =="mli"|dataset_2013_above$iso3_o =="mlt"|dataset_2013_above$iso3_o =="mrt"|dataset_2013_above$iso3_o =="fsm"|dataset_2013_above$iso3_o =="mda"|dataset_2013_above$iso3_o =="mng"|dataset_2013_above$iso3_o =="mne"|dataset_2013_above$iso3_o =="mar"|dataset_2013_above$iso3_o =="moz"|dataset_2013_above$iso3_o =="mmr")
#     # subset the data by countries whose origin is a part of the BRI, I've had to do it in two steps because the executing the command as a whole returned an error
#     
#     
#     dataset_2013_above_bothin_step2c <- subset(dataset_2013_above_bothin_step1b, dataset_2013_above_bothin_step1b$iso3_d =="dom"|dataset_2013_above_bothin_step1b$iso3_d =="ecu"|dataset_2013_above_bothin_step1b$iso3_d =="egy"|dataset_2013_above_bothin_step1b$iso3_d =="slv"|dataset_2013_above_bothin_step1b$iso3_d =="gnq"|dataset_2013_above_bothin_step1b$iso3_d =="est"|dataset_2013_above_bothin_step1b$iso3_d =="eth"|dataset_2013_above_bothin_step1b$iso3_d =="fji"|dataset_2013_above_bothin_step1b$iso3_d =="gab"|dataset_2013_above_bothin_step1b$iso3_d =="gmb"|dataset_2013_above_bothin_step1b$iso3_d =="geo"|dataset_2013_above_bothin_step1b$iso3_d =="gha"|dataset_2013_above_bothin_step1b$iso3_d =="grc"|dataset_2013_above_bothin_step1b$iso3_d =="grd"|dataset_2013_above_bothin_step1b$iso3_d =="gin"|dataset_2013_above_bothin_step1b$iso3_d =="guy"|dataset_2013_above_bothin_step1b$iso3_d =="hun"|dataset_2013_above_bothin_step1b$iso3_d =="idn"|dataset_2013_above_bothin_step1b$iso3_d =="irn"|dataset_2013_above_bothin_step1b$iso3_d =="irq"|dataset_2013_above_bothin_step1b$iso3_d =="isr"|dataset_2013_above_bothin_step1b$iso3_d =="ita"|dataset_2013_above_bothin_step1b$iso3_d =="jam"|dataset_2013_above_bothin_step1b$iso3_d =="jor"|dataset_2013_above_bothin_step1b$iso3_d =="kaz"|dataset_2013_above_bothin_step1b$iso3_d =="kgz"|dataset_2013_above_bothin_step1b$iso3_d =="ken"|dataset_2013_above_bothin_step1b$iso3_d =="kor"|dataset_2013_above_bothin_step1b$iso3_d =="kwt"|dataset_2013_above_bothin_step1b$iso3_d =="lao"|dataset_2013_above_bothin_step1b$iso3_d =="lva"|dataset_2013_above_bothin_step1b$iso3_d =="lbn"|dataset_2013_above_bothin_step1b$iso3_d =="lbr"|dataset_2013_above_bothin_step1b$iso3_d =="lby"|dataset_2013_above_bothin_step1b$iso3_d =="ltu"|dataset_2013_above_bothin_step1b$iso3_d =="lux"|dataset_2013_above_bothin_step1b$iso3_d =="mdg"|dataset_2013_above_bothin_step1b$iso3_d =="mys"|dataset_2013_above_bothin_step1b$iso3_d =="mdv"|dataset_2013_above_bothin_step1b$iso3_d =="mli"|dataset_2013_above_bothin_step1b$iso3_d =="mlt"|dataset_2013_above_bothin_step1b$iso3_d =="mrt"|dataset_2013_above_bothin_step1b$iso3_d =="fsm"|dataset_2013_above_bothin_step1b$iso3_d =="mda"|dataset_2013_above_bothin_step1b$iso3_d =="mng"|dataset_2013_above_bothin_step1b$iso3_d =="mne"|dataset_2013_above_bothin_step1b$iso3_d =="mar"|dataset_2013_above_bothin_step1b$iso3_d =="moz"|dataset_2013_above_bothin_step1b$iso3_d =="mmr")
#     dataset_2013_above_bothin_step2b <- subset(dataset_2013_above_bothin_step1b, dataset_2013_above_bothin_step1b $iso3_d == "chn"|dataset_2013_above_bothin_step1b$iso3_d =="afg"|dataset_2013_above_bothin_step1b$iso3_d =="alb"|dataset_2013_above_bothin_step1b$iso3_d =="dza"|dataset_2013_above_bothin_step1b$iso3_d =="ago"|dataset_2013_above_bothin_step1b$iso3_d =="atg"|dataset_2013_above_bothin_step1b$iso3_d =="arm"|dataset_2013_above_bothin_step1b$iso3_d =="aut"|dataset_2013_above_bothin_step1b$iso3_d =="aze"|dataset_2013_above_bothin_step1b$iso3_d =="bhr"|dataset_2013_above_bothin_step1b$iso3_d =="bgd"|dataset_2013_above_bothin_step1b$iso3_d =="brb"|dataset_2013_above_bothin_step1b$iso3_d =="blr"|dataset_2013_above_bothin_step1b$iso3_d =="btn"|dataset_2013_above_bothin_step1b$iso3_d =="bhu"|dataset_2013_above_bothin_step1b$iso3_d =="bol"|dataset_2013_above_bothin_step1b$iso3_d =="bih"|dataset_2013_above_bothin_step1b$iso3_d =="brn"|dataset_2013_above_bothin_step1b$iso3_d =="bgr"|dataset_2013_above_bothin_step1b$iso3_d =="bdi"|dataset_2013_above_bothin_step1b$iso3_d =="khm"|dataset_2013_above_bothin_step1b$iso3_d =="cmr"|dataset_2013_above_bothin_step1b$iso3_d =="cpv"|dataset_2013_above_bothin_step1b$iso3_d =="tcd"|dataset_2013_above_bothin_step1b$iso3_d =="chl"|dataset_2013_above_bothin_step1b$iso3_d =="cog"|dataset_2013_above_bothin_step1b$iso3_d =="cok"|dataset_2013_above_bothin_step1b$iso3_d =="crc"|dataset_2013_above_bothin_step1b$iso3_d =="cri"|dataset_2013_above_bothin_step1b$iso3_d =="civ"|dataset_2013_above_bothin_step1b$iso3_d =="hrv"|dataset_2013_above_bothin_step1b$iso3_d =="cub"|dataset_2013_above_bothin_step1b$iso3_d =="cyp"|dataset_2013_above_bothin_step1b$iso3_d =="cze"|dataset_2013_above_bothin_step1b$iso3_d =="dji"|dataset_2013_above_bothin_step1b$iso3_d =="dma")
#     dataset_2013_above_bothin_step2a <- subset(dataset_2013_above_bothin_step1b, dataset_2013_above_bothin_step1b$iso3_d =="nam"|dataset_2013_above_bothin_step1b$iso3_d =="npl"|dataset_2013_above_bothin_step1b$iso3_d =="nzl"|dataset_2013_above_bothin_step1b$iso3_d =="nga"|dataset_2013_above_bothin_step1b$iso3_d =="niu"|dataset_2013_above_bothin_step1b$iso3_d =="mkd"|dataset_2013_above_bothin_step1b$iso3_d =="omn"|dataset_2013_above_bothin_step1b$iso3_d =="pak"|dataset_2013_above_bothin_step1b$iso3_d =="pse"|dataset_2013_above_bothin_step1b$iso3_d =="pan"|dataset_2013_above_bothin_step1b$iso3_d =="png"|dataset_2013_above_bothin_step1b$iso3_d =="per"|dataset_2013_above_bothin_step1b$iso3_d =="phl"|dataset_2013_above_bothin_step1b$iso3_d =="pol"|dataset_2013_above_bothin_step1b$iso3_d =="prt"|dataset_2013_above_bothin_step1b$iso3_d =="qat"|dataset_2013_above_bothin_step1b$iso3_d =="rou"|dataset_2013_above_bothin_step1b$iso3_d =="rus"|dataset_2013_above_bothin_step1b$iso3_d =="rwa"|dataset_2013_above_bothin_step1b$iso3_d =="wsm"|dataset_2013_above_bothin_step1b$iso3_d =="sau"|dataset_2013_above_bothin_step1b$iso3_d =="sen"|dataset_2013_above_bothin_step1b$iso3_d =="srb"|dataset_2013_above_bothin_step1b$iso3_d =="spa"|dataset_2013_above_bothin_step1b$iso3_d =="syc"|dataset_2013_above_bothin_step1b$iso3_d =="sle"|dataset_2013_above_bothin_step1b$iso3_d =="sgp"|dataset_2013_above_bothin_step1b$iso3_d =="svk"|dataset_2013_above_bothin_step1b$iso3_d =="svn"|dataset_2013_above_bothin_step1b$iso3_d =="som"|dataset_2013_above_bothin_step1b$iso3_d =="zaf"|dataset_2013_above_bothin_step1b$iso3_d =="ssd"|dataset_2013_above_bothin_step1b$iso3_d =="lka"|dataset_2013_above_bothin_step1b$iso3_d =="sdn"|dataset_2013_above_bothin_step1b$iso3_d =="sur"|dataset_2013_above_bothin_step1b$iso3_d =="syr"|dataset_2013_above_bothin_step1b$iso3_d =="tjk"|dataset_2013_above_bothin_step1b$iso3_d =="tza"|dataset_2013_above_bothin_step1b$iso3_d =="tha"|dataset_2013_above_bothin_step1b$iso3_d =="tls"|dataset_2013_above_bothin_step1b$iso3_d =="tgo"|dataset_2013_above_bothin_step1b$iso3_d =="ton"|dataset_2013_above_bothin_step1b$iso3_d =="tto"|dataset_2013_above_bothin_step1b$iso3_d =="tun"|dataset_2013_above_bothin_step1b$iso3_d =="tur"|dataset_2013_above_bothin_step1b$iso3_d =="tkm"|dataset_2013_above_bothin_step1b$iso3_d =="uga"|dataset_2013_above_bothin_step1b$iso3_d =="ukr"|dataset_2013_above_bothin_step1b$iso3_d =="are"|dataset_2013_above_bothin_step1b$iso3_d =="ury"|dataset_2013_above_bothin_step1b$iso3_d =="uzb"|dataset_2013_above_bothin_step1b$iso3_d =="vut"|dataset_2013_above_bothin_step1b$iso3_d =="ven"|dataset_2013_above_bothin_step1b$iso3_d =="vnm"|dataset_2013_above_bothin_step1b$iso3_d =="yem"|dataset_2013_above_bothin_step1b$iso3_d =="zmb"|dataset_2013_above_bothin_step1b$iso3_d =="zwe")
#     dataset_2013_above_bothin_step2d <- subset(dataset_2013_above_bothin_step1, dataset_2013_above_bothin_step1$iso3_d =="nam"|dataset_2013_above_bothin_step1$iso3_d =="npl"|dataset_2013_above_bothin_step1$iso3_d =="nzl"|dataset_2013_above_bothin_step1$iso3_d =="nga"|dataset_2013_above_bothin_step1$iso3_d =="niu"|dataset_2013_above_bothin_step1$iso3_d =="mkd"|dataset_2013_above_bothin_step1$iso3_d =="omn"|dataset_2013_above_bothin_step1$iso3_d =="pak"|dataset_2013_above_bothin_step1$iso3_d =="pse"|dataset_2013_above_bothin_step1$iso3_d =="pan"|dataset_2013_above_bothin_step1$iso3_d =="png"|dataset_2013_above_bothin_step1$iso3_d =="per"|dataset_2013_above_bothin_step1$iso3_d =="phl"|dataset_2013_above_bothin_step1$iso3_d =="pol"|dataset_2013_above_bothin_step1$iso3_d =="prt"|dataset_2013_above_bothin_step1$iso3_d =="qat"|dataset_2013_above_bothin_step1$iso3_d =="rou"|dataset_2013_above_bothin_step1$iso3_d =="rus"|dataset_2013_above_bothin_step1$iso3_d =="rwa"|dataset_2013_above_bothin_step1$iso3_d =="wsm"|dataset_2013_above_bothin_step1$iso3_d =="sau"|dataset_2013_above_bothin_step1$iso3_d =="sen"|dataset_2013_above_bothin_step1$iso3_d =="srb"|dataset_2013_above_bothin_step1$iso3_d =="spa"|dataset_2013_above_bothin_step1$iso3_d =="syc"|dataset_2013_above_bothin_step1$iso3_d =="sle"|dataset_2013_above_bothin_step1$iso3_d =="sgp"|dataset_2013_above_bothin_step1$iso3_d =="svk"|dataset_2013_above_bothin_step1$iso3_d =="svn"|dataset_2013_above_bothin_step1$iso3_d =="som"|dataset_2013_above_bothin_step1$iso3_d =="zaf"|dataset_2013_above_bothin_step1$iso3_d =="ssd"|dataset_2013_above_bothin_step1$iso3_d =="lka"|dataset_2013_above_bothin_step1$iso3_d =="sdn"|dataset_2013_above_bothin_step1$iso3_d =="sur"|dataset_2013_above_bothin_step1$iso3_d =="syr"|dataset_2013_above_bothin_step1$iso3_d =="tjk"|dataset_2013_above_bothin_step1$iso3_d =="tza"|dataset_2013_above_bothin_step1$iso3_d =="tha"|dataset_2013_above_bothin_step1$iso3_d =="tls"|dataset_2013_above_bothin_step1$iso3_d =="tgo"|dataset_2013_above_bothin_step1$iso3_d =="ton"|dataset_2013_above_bothin_step1$iso3_d =="tto"|dataset_2013_above_bothin_step1$iso3_d =="tun"|dataset_2013_above_bothin_step1$iso3_d =="tur"|dataset_2013_above_bothin_step1$iso3_d =="tkm"|dataset_2013_above_bothin_step1$iso3_d =="uga"|dataset_2013_above_bothin_step1$iso3_d =="ukr"|dataset_2013_above_bothin_step1$iso3_d =="are"|dataset_2013_above_bothin_step1$iso3_d =="ury"|dataset_2013_above_bothin_step1$iso3_d =="uzb"|dataset_2013_above_bothin_step1$iso3_d =="vut"|dataset_2013_above_bothin_step1$iso3_d =="ven"|dataset_2013_above_bothin_step1$iso3_d =="vnm"|dataset_2013_above_bothin_step1$iso3_d =="yem"|dataset_2013_above_bothin_step1$iso3_d =="zmb"|dataset_2013_above_bothin_step1$iso3_d =="zwe")
#     dataset_2013_above_bothin_step2e <- subset(dataset_2013_above_bothin_step1, dataset_2013_above_bothin_step1 $iso3_d == "chn"|dataset_2013_above_bothin_step1$iso3_d =="afg"|dataset_2013_above_bothin_step1$iso3_d =="alb"|dataset_2013_above_bothin_step1$iso3_d =="dza"|dataset_2013_above_bothin_step1$iso3_d =="ago"|dataset_2013_above_bothin_step1$iso3_d =="atg"|dataset_2013_above_bothin_step1$iso3_d =="arm"|dataset_2013_above_bothin_step1$iso3_d =="aut"|dataset_2013_above_bothin_step1$iso3_d =="aze"|dataset_2013_above_bothin_step1$iso3_d =="bhr"|dataset_2013_above_bothin_step1$iso3_d =="bgd"|dataset_2013_above_bothin_step1$iso3_d =="brb"|dataset_2013_above_bothin_step1$iso3_d =="blr"|dataset_2013_above_bothin_step1$iso3_d =="btn"|dataset_2013_above_bothin_step1$iso3_d =="bhu"|dataset_2013_above_bothin_step1$iso3_d =="bol"|dataset_2013_above_bothin_step1$iso3_d =="bih"|dataset_2013_above_bothin_step1$iso3_d =="brn"|dataset_2013_above_bothin_step1$iso3_d =="bgr"|dataset_2013_above_bothin_step1$iso3_d =="bdi"|dataset_2013_above_bothin_step1$iso3_d =="khm"|dataset_2013_above_bothin_step1$iso3_d =="cmr"|dataset_2013_above_bothin_step1$iso3_d =="cpv"|dataset_2013_above_bothin_step1$iso3_d =="tcd"|dataset_2013_above_bothin_step1$iso3_d =="chl"|dataset_2013_above_bothin_step1$iso3_d =="cog"|dataset_2013_above_bothin_step1$iso3_d =="cok"|dataset_2013_above_bothin_step1$iso3_d =="crc"|dataset_2013_above_bothin_step1$iso3_d =="cri"|dataset_2013_above_bothin_step1$iso3_d =="civ"|dataset_2013_above_bothin_step1$iso3_d =="hrv"|dataset_2013_above_bothin_step1$iso3_d =="cub"|dataset_2013_above_bothin_step1$iso3_d =="cyp"|dataset_2013_above_bothin_step1$iso3_d =="cze"|dataset_2013_above_bothin_step1$iso3_d =="dji"|dataset_2013_above_bothin_step1$iso3_d =="dma")
#     dataset_2013_above_bothin_step2f <- subset(dataset_2013_above_bothin_step1, dataset_2013_above_bothin_step1$iso3_d =="dom"|dataset_2013_above_bothin_step1$iso3_d =="ecu"|dataset_2013_above_bothin_step1$iso3_d =="egy"|dataset_2013_above_bothin_step1$iso3_d =="slv"|dataset_2013_above_bothin_step1$iso3_d =="gnq"|dataset_2013_above_bothin_step1$iso3_d =="est"|dataset_2013_above_bothin_step1$iso3_d =="eth"|dataset_2013_above_bothin_step1$iso3_d =="fji"|dataset_2013_above_bothin_step1$iso3_d =="gab"|dataset_2013_above_bothin_step1$iso3_d =="gmb"|dataset_2013_above_bothin_step1$iso3_d =="geo"|dataset_2013_above_bothin_step1$iso3_d =="gha"|dataset_2013_above_bothin_step1$iso3_d =="grc"|dataset_2013_above_bothin_step1$iso3_d =="grd"|dataset_2013_above_bothin_step1$iso3_d =="gin"|dataset_2013_above_bothin_step1$iso3_d =="guy"|dataset_2013_above_bothin_step1$iso3_d =="hun"|dataset_2013_above_bothin_step1$iso3_d =="idn"|dataset_2013_above_bothin_step1$iso3_d =="irn"|dataset_2013_above_bothin_step1$iso3_d =="irq"|dataset_2013_above_bothin_step1$iso3_d =="isr"|dataset_2013_above_bothin_step1$iso3_d =="ita"|dataset_2013_above_bothin_step1$iso3_d =="jam"|dataset_2013_above_bothin_step1$iso3_d =="jor"|dataset_2013_above_bothin_step1$iso3_d =="kaz"|dataset_2013_above_bothin_step1$iso3_d =="kgz"|dataset_2013_above_bothin_step1$iso3_d =="ken"|dataset_2013_above_bothin_step1$iso3_d =="kor"|dataset_2013_above_bothin_step1$iso3_d =="kwt"|dataset_2013_above_bothin_step1$iso3_d =="lao"|dataset_2013_above_bothin_step1$iso3_d =="lva"|dataset_2013_above_bothin_step1$iso3_d =="lbn"|dataset_2013_above_bothin_step1$iso3_d =="lbr"|dataset_2013_above_bothin_step1$iso3_d =="lby"|dataset_2013_above_bothin_step1$iso3_d =="ltu"|dataset_2013_above_bothin_step1$iso3_d =="lux"|dataset_2013_above_bothin_step1$iso3_d =="mdg"|dataset_2013_above_bothin_step1$iso3_d =="mys"|dataset_2013_above_bothin_step1$iso3_d =="mdv"|dataset_2013_above_bothin_step1$iso3_d =="mli"|dataset_2013_above_bothin_step1$iso3_d =="mlt"|dataset_2013_above_bothin_step1$iso3_d =="mrt"|dataset_2013_above_bothin_step1$iso3_d =="fsm"|dataset_2013_above_bothin_step1$iso3_d =="mda"|dataset_2013_above_bothin_step1$iso3_d =="mng"|dataset_2013_above_bothin_step1$iso3_d =="mne"|dataset_2013_above_bothin_step1$iso3_d =="mar"|dataset_2013_above_bothin_step1$iso3_d =="moz"|dataset_2013_above_bothin_step1$iso3_d =="mmr")
#     # subset the data by destination; had to do each of the parts from step 1 in three steps therefore having six parts in step 2
#     
#     
#     dataset_2013_above_bothin_step3a <- full_join(dataset_2013_above_bothin_step2a, dataset_2013_above_bothin_step2b)
#     dataset_2013_above_bothin_step3b <- full_join(dataset_2013_above_bothin_step2c, dataset_2013_above_bothin_step2d)
#     dataset_2013_above_bothin_step3c <- full_join(dataset_2013_above_bothin_step2e, dataset_2013_above_bothin_step2f)
#     
#     dataset_2013_above_bothin_step4 <- full_join(dataset_2013_above_bothin_step3a, dataset_2013_above_bothin_step3b)
#     
#     dataset_2013_above_bothin_final_old <- full_join(dataset_2013_above_bothin_step4, dataset_2013_above_bothin_step3c)
#     # subset and join data in such a way that I have a dataset where the origin and the destination are both part of BRI
#     
#     
#     rm(dataset_2013_above_bothin_step2c, dataset_2013_above_bothin_step2a, dataset_2013_above_bothin_step2b, dataset_2013_above_bothin_step2d, dataset_2013_above_bothin_step2e, dataset_2013_above_bothin_step2f)
#     rm(dataset_2013_above_bothin_join)
#     rm(dataset_2013_above_bothin_step1, dataset_2013_above_bothin_step1b)
#     rm(dataset_2013_above_bothin_step3a, dataset_2013_above_bothin_step3b, dataset_2013_above_bothin_step3c, dataset_2013_above_bothin_step4)
#     # just remove the fuzz
# 
# 
# 
# # DO THE EXACT SAME THING BUT NOT EXCLUSIVE TO 2013+
#       total_dataset_bothin_step1b <- subset(total_dataset, total_dataset$iso3_o =="nam"|total_dataset$iso3_o =="npl"|total_dataset$iso3_o =="nzl"|total_dataset$iso3_o =="nga"|total_dataset$iso3_o =="niu"|total_dataset$iso3_o =="mkd"|total_dataset$iso3_o =="omn"|total_dataset$iso3_o =="pak"|total_dataset$iso3_o =="pse"|total_dataset$iso3_o =="pan"|total_dataset$iso3_o =="png"|total_dataset$iso3_o =="per"|total_dataset$iso3_o =="phl"|total_dataset$iso3_o =="pol"|total_dataset$iso3_o =="prt"|total_dataset$iso3_o =="qat"|total_dataset$iso3_o =="rou"|total_dataset$iso3_o =="rus"|total_dataset$iso3_o =="rwa"|total_dataset$iso3_o =="wsm"|total_dataset$iso3_o =="sau"|total_dataset$iso3_o =="sen"|total_dataset$iso3_o =="srb"|total_dataset$iso3_o =="spa"|total_dataset$iso3_o =="syc"|total_dataset$iso3_o =="sle"|total_dataset$iso3_o =="sgp"|total_dataset$iso3_o =="svk"|total_dataset$iso3_o =="svn"|total_dataset$iso3_o =="som"|total_dataset$iso3_o =="zaf"|total_dataset$iso3_o =="ssd"|total_dataset$iso3_o =="lka"|total_dataset$iso3_o =="sdn"|total_dataset$iso3_o =="sur"|total_dataset$iso3_o =="syr"|total_dataset$iso3_o =="tjk"|total_dataset$iso3_o =="tza"|total_dataset$iso3_o =="tha"|total_dataset$iso3_o =="tls"|total_dataset$iso3_o =="tgo"|total_dataset$iso3_o =="ton"|total_dataset$iso3_o =="tto"|total_dataset$iso3_o =="tun"|total_dataset$iso3_o =="tur"|total_dataset$iso3_o =="tkm"|total_dataset$iso3_o =="uga"|total_dataset$iso3_o =="ukr"|total_dataset$iso3_o =="are"|total_dataset$iso3_o =="ury"|total_dataset$iso3_o =="uzb"|total_dataset$iso3_o =="vut"|total_dataset$iso3_o =="ven"|total_dataset$iso3_o =="vnm"|total_dataset$iso3_o =="yem"|total_dataset$iso3_o =="zmb"|total_dataset$iso3_o =="zwe")
#       total_dataset_bothin_step1a <- subset(total_dataset, total_dataset $iso3_o == "chn"|total_dataset$iso3_o =="afg"|total_dataset$iso3_o =="alb"|total_dataset$iso3_o =="dza"|total_dataset$iso3_o =="ago"|total_dataset$iso3_o =="atg"|total_dataset$iso3_o =="arm"|total_dataset$iso3_o =="aut"|total_dataset$iso3_o =="aze"|total_dataset$iso3_o =="bhr"|total_dataset$iso3_o =="bgd"|total_dataset$iso3_o =="brb"|total_dataset$iso3_o =="blr"|total_dataset$iso3_o =="btn"|total_dataset$iso3_o =="bhu"|total_dataset$iso3_o =="bol"|total_dataset$iso3_o =="bih"|total_dataset$iso3_o =="brn"|total_dataset$iso3_o =="bgr"|total_dataset$iso3_o =="bdi"|total_dataset$iso3_o =="khm"|total_dataset$iso3_o =="cmr"|total_dataset$iso3_o =="cpv"|total_dataset$iso3_o =="tcd"|total_dataset$iso3_o =="chl"|total_dataset$iso3_o =="cog"|total_dataset$iso3_o =="cok"|total_dataset$iso3_o =="crc"|total_dataset$iso3_o =="cri"|total_dataset$iso3_o =="civ"|total_dataset$iso3_o =="hrv"|total_dataset$iso3_o =="cub"|total_dataset$iso3_o =="cyp"|total_dataset$iso3_o =="cze"|total_dataset$iso3_o =="dji"|total_dataset$iso3_o =="dma"|total_dataset$iso3_o =="dom"|total_dataset$iso3_o =="ecu"|total_dataset$iso3_o =="egy"|total_dataset$iso3_o =="slv"|total_dataset$iso3_o =="gnq"|total_dataset$iso3_o =="est"|total_dataset$iso3_o =="eth"|total_dataset$iso3_o =="fji"|total_dataset$iso3_o =="gab"|total_dataset$iso3_o =="gmb"|total_dataset$iso3_o =="geo"|total_dataset$iso3_o =="gha"|total_dataset$iso3_o =="grc"|total_dataset$iso3_o =="grd"|total_dataset$iso3_o =="gin"|total_dataset$iso3_o =="guy"|total_dataset$iso3_o =="hun"|total_dataset$iso3_o =="idn"|total_dataset$iso3_o =="irn"|total_dataset$iso3_o =="irq"|total_dataset$iso3_o =="isr"|total_dataset$iso3_o =="ita"|total_dataset$iso3_o =="jam"|total_dataset$iso3_o =="jor"|total_dataset$iso3_o =="kaz"|total_dataset$iso3_o =="kgz"|total_dataset$iso3_o =="ken"|total_dataset$iso3_o =="kor"|total_dataset$iso3_o =="kwt"|total_dataset$iso3_o =="lao"|total_dataset$iso3_o =="lva"|total_dataset$iso3_o =="lbn"|total_dataset$iso3_o =="lbr"|total_dataset$iso3_o =="lby"|total_dataset$iso3_o =="ltu"|total_dataset$iso3_o =="lux"|total_dataset$iso3_o =="mdg"|total_dataset$iso3_o =="mys"|total_dataset$iso3_o =="mdv"|total_dataset$iso3_o =="mli"|total_dataset$iso3_o =="mlt"|total_dataset$iso3_o =="mrt"|total_dataset$iso3_o =="fsm"|total_dataset$iso3_o =="mda"|total_dataset$iso3_o =="mng"|total_dataset$iso3_o =="mne"|total_dataset$iso3_o =="mar"|total_dataset$iso3_o =="moz"|total_dataset$iso3_o =="mmr")
#       # subset the data by countries whose origin is a part of the BRI, I've had to do it in two steps because the executing the command as a whole returned an error
#       
#       
#       total_dataset_bothin_step2c <- subset(total_dataset_bothin_step1b, total_dataset_bothin_step1b$iso3_d =="dom"|total_dataset_bothin_step1b$iso3_d =="ecu"|total_dataset_bothin_step1b$iso3_d =="egy"|total_dataset_bothin_step1b$iso3_d =="slv"|total_dataset_bothin_step1b$iso3_d =="gnq"|total_dataset_bothin_step1b$iso3_d =="est"|total_dataset_bothin_step1b$iso3_d =="eth"|total_dataset_bothin_step1b$iso3_d =="fji"|total_dataset_bothin_step1b$iso3_d =="gab"|total_dataset_bothin_step1b$iso3_d =="gmb"|total_dataset_bothin_step1b$iso3_d =="geo"|total_dataset_bothin_step1b$iso3_d =="gha"|total_dataset_bothin_step1b$iso3_d =="grc"|total_dataset_bothin_step1b$iso3_d =="grd"|total_dataset_bothin_step1b$iso3_d =="gin"|total_dataset_bothin_step1b$iso3_d =="guy"|total_dataset_bothin_step1b$iso3_d =="hun"|total_dataset_bothin_step1b$iso3_d =="idn"|total_dataset_bothin_step1b$iso3_d =="irn"|total_dataset_bothin_step1b$iso3_d =="irq"|total_dataset_bothin_step1b$iso3_d =="isr"|total_dataset_bothin_step1b$iso3_d =="ita"|total_dataset_bothin_step1b$iso3_d =="jam"|total_dataset_bothin_step1b$iso3_d =="jor"|total_dataset_bothin_step1b$iso3_d =="kaz"|total_dataset_bothin_step1b$iso3_d =="kgz"|total_dataset_bothin_step1b$iso3_d =="ken"|total_dataset_bothin_step1b$iso3_d =="kor"|total_dataset_bothin_step1b$iso3_d =="kwt"|total_dataset_bothin_step1b$iso3_d =="lao"|total_dataset_bothin_step1b$iso3_d =="lva"|total_dataset_bothin_step1b$iso3_d =="lbn"|total_dataset_bothin_step1b$iso3_d =="lbr"|total_dataset_bothin_step1b$iso3_d =="lby"|total_dataset_bothin_step1b$iso3_d =="ltu"|total_dataset_bothin_step1b$iso3_d =="lux"|total_dataset_bothin_step1b$iso3_d =="mdg"|total_dataset_bothin_step1b$iso3_d =="mys"|total_dataset_bothin_step1b$iso3_d =="mdv"|total_dataset_bothin_step1b$iso3_d =="mli"|total_dataset_bothin_step1b$iso3_d =="mlt"|total_dataset_bothin_step1b$iso3_d =="mrt"|total_dataset_bothin_step1b$iso3_d =="fsm"|total_dataset_bothin_step1b$iso3_d =="mda"|total_dataset_bothin_step1b$iso3_d =="mng"|total_dataset_bothin_step1b$iso3_d =="mne"|total_dataset_bothin_step1b$iso3_d =="mar"|total_dataset_bothin_step1b$iso3_d =="moz"|total_dataset_bothin_step1b$iso3_d =="mmr")
#       total_dataset_bothin_step2b <- subset(total_dataset_bothin_step1b, total_dataset_bothin_step1b $iso3_d == "chn"|total_dataset_bothin_step1b$iso3_d =="afg"|total_dataset_bothin_step1b$iso3_d =="alb"|total_dataset_bothin_step1b$iso3_d =="dza"|total_dataset_bothin_step1b$iso3_d =="ago"|total_dataset_bothin_step1b$iso3_d =="atg"|total_dataset_bothin_step1b$iso3_d =="arm"|total_dataset_bothin_step1b$iso3_d =="aut"|total_dataset_bothin_step1b$iso3_d =="aze"|total_dataset_bothin_step1b$iso3_d =="bhr"|total_dataset_bothin_step1b$iso3_d =="bgd"|total_dataset_bothin_step1b$iso3_d =="brb"|total_dataset_bothin_step1b$iso3_d =="blr"|total_dataset_bothin_step1b$iso3_d =="btn"|total_dataset_bothin_step1b$iso3_d =="bhu"|total_dataset_bothin_step1b$iso3_d =="bol"|total_dataset_bothin_step1b$iso3_d =="bih"|total_dataset_bothin_step1b$iso3_d =="brn"|total_dataset_bothin_step1b$iso3_d =="bgr"|total_dataset_bothin_step1b$iso3_d =="bdi"|total_dataset_bothin_step1b$iso3_d =="khm"|total_dataset_bothin_step1b$iso3_d =="cmr"|total_dataset_bothin_step1b$iso3_d =="cpv"|total_dataset_bothin_step1b$iso3_d =="tcd"|total_dataset_bothin_step1b$iso3_d =="chl"|total_dataset_bothin_step1b$iso3_d =="cog"|total_dataset_bothin_step1b$iso3_d =="cok"|total_dataset_bothin_step1b$iso3_d =="crc"|total_dataset_bothin_step1b$iso3_d =="cri"|total_dataset_bothin_step1b$iso3_d =="civ"|total_dataset_bothin_step1b$iso3_d =="hrv"|total_dataset_bothin_step1b$iso3_d =="cub"|total_dataset_bothin_step1b$iso3_d =="cyp"|total_dataset_bothin_step1b$iso3_d =="cze"|total_dataset_bothin_step1b$iso3_d =="dji"|total_dataset_bothin_step1b$iso3_d =="dma")
#       total_dataset_bothin_step2a <- subset(total_dataset_bothin_step1b, total_dataset_bothin_step1b$iso3_d =="nam"|total_dataset_bothin_step1b$iso3_d =="npl"|total_dataset_bothin_step1b$iso3_d =="nzl"|total_dataset_bothin_step1b$iso3_d =="nga"|total_dataset_bothin_step1b$iso3_d =="niu"|total_dataset_bothin_step1b$iso3_d =="mkd"|total_dataset_bothin_step1b$iso3_d =="omn"|total_dataset_bothin_step1b$iso3_d =="pak"|total_dataset_bothin_step1b$iso3_d =="pse"|total_dataset_bothin_step1b$iso3_d =="pan"|total_dataset_bothin_step1b$iso3_d =="png"|total_dataset_bothin_step1b$iso3_d =="per"|total_dataset_bothin_step1b$iso3_d =="phl"|total_dataset_bothin_step1b$iso3_d =="pol"|total_dataset_bothin_step1b$iso3_d =="prt"|total_dataset_bothin_step1b$iso3_d =="qat"|total_dataset_bothin_step1b$iso3_d =="rou"|total_dataset_bothin_step1b$iso3_d =="rus"|total_dataset_bothin_step1b$iso3_d =="rwa"|total_dataset_bothin_step1b$iso3_d =="wsm"|total_dataset_bothin_step1b$iso3_d =="sau"|total_dataset_bothin_step1b$iso3_d =="sen"|total_dataset_bothin_step1b$iso3_d =="srb"|total_dataset_bothin_step1b$iso3_d =="spa"|total_dataset_bothin_step1b$iso3_d =="syc"|total_dataset_bothin_step1b$iso3_d =="sle"|total_dataset_bothin_step1b$iso3_d =="sgp"|total_dataset_bothin_step1b$iso3_d =="svk"|total_dataset_bothin_step1b$iso3_d =="svn"|total_dataset_bothin_step1b$iso3_d =="som"|total_dataset_bothin_step1b$iso3_d =="zaf"|total_dataset_bothin_step1b$iso3_d =="ssd"|total_dataset_bothin_step1b$iso3_d =="lka"|total_dataset_bothin_step1b$iso3_d =="sdn"|total_dataset_bothin_step1b$iso3_d =="sur"|total_dataset_bothin_step1b$iso3_d =="syr"|total_dataset_bothin_step1b$iso3_d =="tjk"|total_dataset_bothin_step1b$iso3_d =="tza"|total_dataset_bothin_step1b$iso3_d =="tha"|total_dataset_bothin_step1b$iso3_d =="tls"|total_dataset_bothin_step1b$iso3_d =="tgo"|total_dataset_bothin_step1b$iso3_d =="ton"|total_dataset_bothin_step1b$iso3_d =="tto"|total_dataset_bothin_step1b$iso3_d =="tun"|total_dataset_bothin_step1b$iso3_d =="tur"|total_dataset_bothin_step1b$iso3_d =="tkm"|total_dataset_bothin_step1b$iso3_d =="uga"|total_dataset_bothin_step1b$iso3_d =="ukr"|total_dataset_bothin_step1b$iso3_d =="are"|total_dataset_bothin_step1b$iso3_d =="ury"|total_dataset_bothin_step1b$iso3_d =="uzb"|total_dataset_bothin_step1b$iso3_d =="vut"|total_dataset_bothin_step1b$iso3_d =="ven"|total_dataset_bothin_step1b$iso3_d =="vnm"|total_dataset_bothin_step1b$iso3_d =="yem"|total_dataset_bothin_step1b$iso3_d =="zmb"|total_dataset_bothin_step1b$iso3_d =="zwe")
#       total_dataset_bothin_step2d <- subset(total_dataset_bothin_step1a, total_dataset_bothin_step1a$iso3_d =="nam"|total_dataset_bothin_step1a$iso3_d =="npl"|total_dataset_bothin_step1a$iso3_d =="nzl"|total_dataset_bothin_step1a$iso3_d =="nga"|total_dataset_bothin_step1a$iso3_d =="niu"|total_dataset_bothin_step1a$iso3_d =="mkd"|total_dataset_bothin_step1a$iso3_d =="omn"|total_dataset_bothin_step1a$iso3_d =="pak"|total_dataset_bothin_step1a$iso3_d =="pse"|total_dataset_bothin_step1a$iso3_d =="pan"|total_dataset_bothin_step1a$iso3_d =="png"|total_dataset_bothin_step1a$iso3_d =="per"|total_dataset_bothin_step1a$iso3_d =="phl"|total_dataset_bothin_step1a$iso3_d =="pol"|total_dataset_bothin_step1a$iso3_d =="prt"|total_dataset_bothin_step1a$iso3_d =="qat"|total_dataset_bothin_step1a$iso3_d =="rou"|total_dataset_bothin_step1a$iso3_d =="rus"|total_dataset_bothin_step1a$iso3_d =="rwa"|total_dataset_bothin_step1a$iso3_d =="wsm"|total_dataset_bothin_step1a$iso3_d =="sau"|total_dataset_bothin_step1a$iso3_d =="sen"|total_dataset_bothin_step1a$iso3_d =="srb"|total_dataset_bothin_step1a$iso3_d =="spa"|total_dataset_bothin_step1a$iso3_d =="syc"|total_dataset_bothin_step1a$iso3_d =="sle"|total_dataset_bothin_step1a$iso3_d =="sgp"|total_dataset_bothin_step1a$iso3_d =="svk"|total_dataset_bothin_step1a$iso3_d =="svn"|total_dataset_bothin_step1a$iso3_d =="som"|total_dataset_bothin_step1a$iso3_d =="zaf"|total_dataset_bothin_step1a$iso3_d =="ssd"|total_dataset_bothin_step1a$iso3_d =="lka"|total_dataset_bothin_step1a$iso3_d =="sdn"|total_dataset_bothin_step1a$iso3_d =="sur"|total_dataset_bothin_step1a$iso3_d =="syr"|total_dataset_bothin_step1a$iso3_d =="tjk"|total_dataset_bothin_step1a$iso3_d =="tza"|total_dataset_bothin_step1a$iso3_d =="tha"|total_dataset_bothin_step1a$iso3_d =="tls"|total_dataset_bothin_step1a$iso3_d =="tgo"|total_dataset_bothin_step1a$iso3_d =="ton"|total_dataset_bothin_step1a$iso3_d =="tto"|total_dataset_bothin_step1a$iso3_d =="tun"|total_dataset_bothin_step1a$iso3_d =="tur"|total_dataset_bothin_step1a$iso3_d =="tkm"|total_dataset_bothin_step1a$iso3_d =="uga"|total_dataset_bothin_step1a$iso3_d =="ukr"|total_dataset_bothin_step1a$iso3_d =="are"|total_dataset_bothin_step1a$iso3_d =="ury"|total_dataset_bothin_step1a$iso3_d =="uzb"|total_dataset_bothin_step1a$iso3_d =="vut"|total_dataset_bothin_step1a$iso3_d =="ven"|total_dataset_bothin_step1a$iso3_d =="vnm"|total_dataset_bothin_step1a$iso3_d =="yem"|total_dataset_bothin_step1a$iso3_d =="zmb"|total_dataset_bothin_step1a$iso3_d =="zwe")
#       total_dataset_bothin_step2e <- subset(total_dataset_bothin_step1a, total_dataset_bothin_step1a $iso3_d == "chn"|total_dataset_bothin_step1a$iso3_d =="afg"|total_dataset_bothin_step1a$iso3_d =="alb"|total_dataset_bothin_step1a$iso3_d =="dza"|total_dataset_bothin_step1a$iso3_d =="ago"|total_dataset_bothin_step1a$iso3_d =="atg"|total_dataset_bothin_step1a$iso3_d =="arm"|total_dataset_bothin_step1a$iso3_d =="aut"|total_dataset_bothin_step1a$iso3_d =="aze"|total_dataset_bothin_step1a$iso3_d =="bhr"|total_dataset_bothin_step1a$iso3_d =="bgd"|total_dataset_bothin_step1a$iso3_d =="brb"|total_dataset_bothin_step1a$iso3_d =="blr"|total_dataset_bothin_step1a$iso3_d =="btn"|total_dataset_bothin_step1a$iso3_d =="bhu"|total_dataset_bothin_step1a$iso3_d =="bol"|total_dataset_bothin_step1a$iso3_d =="bih"|total_dataset_bothin_step1a$iso3_d =="brn"|total_dataset_bothin_step1a$iso3_d =="bgr"|total_dataset_bothin_step1a$iso3_d =="bdi"|total_dataset_bothin_step1a$iso3_d =="khm"|total_dataset_bothin_step1a$iso3_d =="cmr"|total_dataset_bothin_step1a$iso3_d =="cpv"|total_dataset_bothin_step1a$iso3_d =="tcd"|total_dataset_bothin_step1a$iso3_d =="chl"|total_dataset_bothin_step1a$iso3_d =="cog"|total_dataset_bothin_step1a$iso3_d =="cok"|total_dataset_bothin_step1a$iso3_d =="crc"|total_dataset_bothin_step1a$iso3_d =="cri"|total_dataset_bothin_step1a$iso3_d =="civ"|total_dataset_bothin_step1a$iso3_d =="hrv"|total_dataset_bothin_step1a$iso3_d =="cub"|total_dataset_bothin_step1a$iso3_d =="cyp"|total_dataset_bothin_step1a$iso3_d =="cze"|total_dataset_bothin_step1a$iso3_d =="dji"|total_dataset_bothin_step1a$iso3_d =="dma")
#       total_dataset_bothin_step2f <- subset(total_dataset_bothin_step1a, total_dataset_bothin_step1a$iso3_d =="dom"|total_dataset_bothin_step1a$iso3_d =="ecu"|total_dataset_bothin_step1a$iso3_d =="egy"|total_dataset_bothin_step1a$iso3_d =="slv"|total_dataset_bothin_step1a$iso3_d =="gnq"|total_dataset_bothin_step1a$iso3_d =="est"|total_dataset_bothin_step1a$iso3_d =="eth"|total_dataset_bothin_step1a$iso3_d =="fji"|total_dataset_bothin_step1a$iso3_d =="gab"|total_dataset_bothin_step1a$iso3_d =="gmb"|total_dataset_bothin_step1a$iso3_d =="geo"|total_dataset_bothin_step1a$iso3_d =="gha"|total_dataset_bothin_step1a$iso3_d =="grc"|total_dataset_bothin_step1a$iso3_d =="grd"|total_dataset_bothin_step1a$iso3_d =="gin"|total_dataset_bothin_step1a$iso3_d =="guy"|total_dataset_bothin_step1a$iso3_d =="hun"|total_dataset_bothin_step1a$iso3_d =="idn"|total_dataset_bothin_step1a$iso3_d =="irn"|total_dataset_bothin_step1a$iso3_d =="irq"|total_dataset_bothin_step1a$iso3_d =="isr"|total_dataset_bothin_step1a$iso3_d =="ita"|total_dataset_bothin_step1a$iso3_d =="jam"|total_dataset_bothin_step1a$iso3_d =="jor"|total_dataset_bothin_step1a$iso3_d =="kaz"|total_dataset_bothin_step1a$iso3_d =="kgz"|total_dataset_bothin_step1a$iso3_d =="ken"|total_dataset_bothin_step1a$iso3_d =="kor"|total_dataset_bothin_step1a$iso3_d =="kwt"|total_dataset_bothin_step1a$iso3_d =="lao"|total_dataset_bothin_step1a$iso3_d =="lva"|total_dataset_bothin_step1a$iso3_d =="lbn"|total_dataset_bothin_step1a$iso3_d =="lbr"|total_dataset_bothin_step1a$iso3_d =="lby"|total_dataset_bothin_step1a$iso3_d =="ltu"|total_dataset_bothin_step1a$iso3_d =="lux"|total_dataset_bothin_step1a$iso3_d =="mdg"|total_dataset_bothin_step1a$iso3_d =="mys"|total_dataset_bothin_step1a$iso3_d =="mdv"|total_dataset_bothin_step1a$iso3_d =="mli"|total_dataset_bothin_step1a$iso3_d =="mlt"|total_dataset_bothin_step1a$iso3_d =="mrt"|total_dataset_bothin_step1a$iso3_d =="fsm"|total_dataset_bothin_step1a$iso3_d =="mda"|total_dataset_bothin_step1a$iso3_d =="mng"|total_dataset_bothin_step1a$iso3_d =="mne"|total_dataset_bothin_step1a$iso3_d =="mar"|total_dataset_bothin_step1a$iso3_d =="moz"|total_dataset_bothin_step1a$iso3_d =="mmr")
#       # subset the data by destination; had to do each of the parts from step 1 in three steps therefore having six parts in step 2
#       
# 
#       total_dataset_bothin_step3a <- full_join(total_dataset_bothin_step2a, total_dataset_bothin_step2b)
#       total_dataset_bothin_step3b <- full_join(total_dataset_bothin_step2c, total_dataset_bothin_step2d)
#       total_dataset_bothin_step3c <- full_join(total_dataset_bothin_step2e, total_dataset_bothin_step2f)
# 
#       total_dataset_bothin_step4 <- full_join(total_dataset_bothin_step3a, total_dataset_bothin_step3b)
# 
#       total_dataset_bothin_final_old <- full_join(total_dataset_bothin_step4, total_dataset_bothin_step3c)
#       # subset and join data in such a way that I have a dataset where the origin and the destination are both part of BRI
# 
# 
#       
#       rm(total_dataset_bothin_step2c, total_dataset_bothin_step2a, total_dataset_bothin_step2b, total_dataset_bothin_step2d, total_dataset_bothin_step2e, total_dataset_bothin_step2f)
#       rm(total_dataset_bothin_step1a, total_dataset_bothin_step1b)
#       rm(total_dataset_bothin_step3a, total_dataset_bothin_step3b, total_dataset_bothin_step3c, total_dataset_bothin_step4)
#       # just remove the fuzz
#       
#       
#       
      
      
      
      
      
      BRI_countries <- read_excel("C:/Users/jakub/Desktop/BRI_countries.xlsx")
      total_dataset_bothin_final <- subset(total_dataset, iso3_o %in% BRI_countries$iso3 & iso3_d %in% BRI_countries$iso3)
      total_dataset_onein_final <- subset(total_dataset, iso3_o %in% BRI_countries$iso3 & !(iso3_d %in% BRI_countries$iso3))
      total_dataset_nonein_final <- subset(total_dataset, !(iso3_o %in% BRI_countries$iso3) & !(iso3_d %in% BRI_countries$iso3))
      total_dataset_destinationin_final <- subset(total_dataset, iso3_d %in% BRI_countries$iso3 & !(iso3_o %in% BRI_countries$iso3))
      # trying a different method of subsetting countries - also doing it on a more accurate (and smaller) list of countries
      # I'll use this method and this list of countries
      
      
      
      
      
      
      
#       
# total_dataset_destinationin_step1 <- full_join(total_dataset_bothin_step3a, total_dataset_bothin_step3b)
# total_dataset_destinationin <- full_join(total_dataset_bothin_step3c, total_dataset_destinationin_step1)
# total_dataset_originin <- full_join(total_dataset_bothin_step1a, total_dataset_bothin_step1b)
# 
# total_dataset_onein_final <- setdiff(total_dataset_originin, total_dataset_destinationin)
# rm(total_dataset_originin, total_dataset_destinationin, total_dataset_destinationin_step1)
# # create a dataset of countries where the destination is in the BRI and a dataset where the origin is in the BRI then subtract one from the other and be left with a dataset where just the origin is a part of the BRI
# 
# 
# dataset_2013_above_onein_final <- setdiff(dataset_2013_above_onein, dataset_2013_above_bothin_final)
# # subtract one dataframe from another in order to have one dataset where only the origin is a part of BRI (the dataset_2013_above_onein is based on observations where the origin is a part of BRI but these observations also include the ones where both countries are a part of BRI)
# 

      
         
# CREATE DUMMY VARIABLES FOR THE ORIGIN OR BOTH THE ORIGIN AND DESTINATION BEING PART OF THE BRI
    dataset_2013_above_bothin_final$dummy_bothin <- 1
    dataset_2013_above_onein_final$dummy_onein <- 1
    dataset_2013_above_bothin_final$dummy_onein <- 0
    dataset_2013_above_onein_final$dummy_bothin <- 0
    
    dataset_2013_above$dummy_onein <- 1
    dataset_2013_above$dummy_bothin <- 0
    dataset_2013_above_none_step1 <- subset(dataset_2013_above, !(iso3_o %in% dataset_2013_above_onein_final$iso3_o & iso3_d %in% dataset_2013_above_onein_final$iso3_d & year %in% dataset_2013_above_onein_final$year))
    dataset_2013_above_none_step1$dummy_onein <- 0
    dataset_2013_above_none_step1$dummy_bothin <- 1
    dataset_2013_above_none <- subset(dataset_2013_above_none_step1, !(iso3_o %in% dataset_2013_above_bothin_final$iso3_o & iso3_d %in% dataset_2013_above_bothin_final$iso3_d & year %in% dataset_2013_above_bothin_final$year))
    # make a dataset that doesn't have origin as a part of BRI, doesn't have origin and destination as a part of BRI in the same row (that means that there are country pairs where just the destination is in BRI or none of them is)
    dataset_2013_above_none$dummy_bothin <- 0
    dataset_2013_above_none$dummy_onein <- 0
    
    
    total_dataset_bothin_final$dummy_bothin <- 1
    total_dataset_onein_final$dummy_onein <- 1
    total_dataset_bothin_final$dummy_onein <- 0
    total_dataset_onein_final$dummy_bothin <- 0
    total_dataset_nonein_final$dummy_onein <- 0
    total_dataset_nonein_final$dummy_bothin <- 0
    total_dataset_destinationin_final$dummy_bothin <- 0
    total_dataset_destinationin_final$dummy_onein <- 0
    # total_dataset$dummy_bothin <- 0
    # total_dataset$dummy_onein <- 1
    # total_dataset_none_step1 <- subset(total_dataset, !(iso3_o %in% total_dataset_onein_final$iso3_o & iso3_d %in% total_dataset_onein_final$iso3_d & year %in% total_dataset_onein_final$year))
    # total_dataset_none_step1$dummy_onein <- 0
    # total_dataset_none_step1$dummy_bothin <- 1
    # total_dataset_none <- subset(total_dataset_none_step1, !(iso3_o %in% total_dataset_bothin_final$iso3_o & iso3_d %in% total_dataset_bothin_final$iso3_d & year %in% total_dataset_bothin_final$year))

    
    total_dataset_dummies_step1 <- full_join(total_dataset_bothin_final, total_dataset_onein_final)
    total_dataset_dummies_step2 <- full_join(total_dataset_dummies_step1, total_dataset_nonein_final)
    total_dataset_dummies <- full_join(total_dataset_dummies_step2, total_dataset_destinationin_final)
    
    
    rm(total_dataset_dummies_step1, total_dataset_dummies_step2, total_dataset_bothin_final, total_dataset_nonein_final, total_dataset_destinationin_final, total_dataset_onein_final)
 
total_dataset_dummies_experiment_graph <- total_dataset_dummies_experiment
total_dataset_dummies_experiment_graph$total_gdp <- total_dataset_dummies_experiment_graph$gdp_o + total_dataset_dummies_experiment_graph$gdp_d

p3 <- ggplot(total_dataset_dummies_experiment, aes(x=total_dataset_dummies_experiment$total_import, y=total_dataset_dummies_experiment$distw)) +
      geom_point(alpha = 0.04) +
      geom_smooth(method=lm , color="red", fill="#69b3a2", se=TRUE) +
      labs(x="Import", y = "Vzdlenost")


ggplot(total_dataset_dummies_experiment_graph, aes(x=total_dataset_dummies_experiment_graph$total_import, y=total_dataset_dummies_experiment_graph$total_gdp)) +
  geom_point(alpha = 0.03) +
  geom_smooth(method=lm, color="red", fill="#69b3a2", se=TRUE) +
  labs(x="Import", y = "HDP")


ggqqplot(log(dataset_2013_above_nozeros$total_import))
ggqqplot(log(dataset_2013_above_final$total_import))
# plot of how close data is to a normal distribution



total_dataset_dummies_nozeros <- total_dataset_dummies_experiment
total_dataset_dummies_nozeros <- subset(total_dataset_dummies_nozeros, total_import == 1)

total_dataset_dummies_ppml <- total_dataset_dummies

# dataset_2013_above_nozeros_ppml <- dataset_2013_above_nozeros
# dataset_2013_above_nozeros_ppml$log_pop_o <- log(dataset_2013_above_nozeros$pop_o)
# dataset_2013_above_nozeros_ppml$log_pop_d <- log(dataset_2013_above_nozeros$pop_d)
# dataset_2013_above_nozeros_ppml$log_area_o <- log(dataset_2013_above_nozeros$area_o)
# dataset_2013_above_nozeros_ppml$log_area_d <- log(dataset_2013_above_nozeros$area_d)
# dataset_2013_above_nozeros_ppml$log_gdp_o <- log(dataset_2013_above_nozeros$gdp_o)
# dataset_2013_above_nozeros_ppml$log_gdp_d <- log(dataset_2013_above_nozeros$gdp_d)
# transform some variables directly into natural logs, since the ppml function isn't capable of doing it


dataset_2013_above_final_ppml <- dataset_2013_above_final
dataset_2013_above_final_ppml$log_pop_o <- log(dataset_2013_above_final_ppml$pop_o)
dataset_2013_above_final_ppml$log_pop_d <- log(dataset_2013_above_final_ppml$pop_d)
dataset_2013_above_final_ppml$log_area_o <- log(dataset_2013_above_final_ppml$area_o)
dataset_2013_above_final_ppml$log_area_d <- log(dataset_2013_above_final_ppml$area_d)
dataset_2013_above_final_ppml$log_gdp_o <- log(dataset_2013_above_final_ppml$gdp_o)
dataset_2013_above_final_ppml$log_gdp_d <- log(dataset_2013_above_final_ppml$gdp_d)
# same here, just for the dataset without zero value observations removed - ppml is able to deal with zero values



total_dataset_dummies_ppml$log_gdp_o <- log(total_dataset_dummies_ppml$gdp_o)
total_dataset_dummies_ppml$log_gdp_d <- log(total_dataset_dummies_ppml$gdp_d)
total_dataset_dummies_experiment_ppml_log <- total_dataset_dummies_experiment_ppml
total_dataset_dummies_experiment_ppml_log$total_import[total_dataset_dummies_experiment_ppml_log$total_import == 0] <- 1
total_dataset_dummies_experiment_ppml_log$log_total_import <- log(total_dataset_dummies_experiment_ppml_log$total_import)


dataset_2013_above_final_ppml$total_import[dataset_2013_above_final_ppml$total_import == 1] <- 0
dataset_2013_above_final_ppml$total_export[dataset_2013_above_final_ppml$total_export == 1] <- 0
total_dataset_dummies_ppml$total_import[total_dataset_dummies_ppml$total_import == 1] <- 0
total_dataset_dummies_ppml$total_export[total_dataset_dummies_ppml$total_export == 1] <- 0
# change the 1 values back to 0


total_dataset_dummies_experiment_ppml <- total_dataset_dummies_experiment

total_dataset_dummies_experiment_ppml$log_gdp_o <- log(total_dataset_dummies_experiment_ppml$gdp_o)
total_dataset_dummies_experiment_ppml$log_gdp_d <- log(total_dataset_dummies_experiment_ppml$gdp_d)

total_dataset_dummies_experiment_ppml$total_import[total_dataset_dummies_experiment_ppml$total_import == 1] <- 0
total_dataset_dummies_experiment_ppml$total_export[total_dataset_dummies_experiment_ppml$total_export == 1] <- 0


total_dataset_dummies_experiment_ppml_log <- total_dataset_dummies_experiment_ppml
total_dataset_dummies_experiment_ppml_log$total_import[total_dataset_dummies_experiment_ppml$total_import == 0] <- 1
total_dataset_dummies_experiment_ppml_log$log_total_import <- log(total_dataset_dummies_experiment_ppml_log$total_import)





fit_total_dummies_experiment <- lm(log(total_import) ~ year + contig + comlang_off + comlang_ethno + comcol + log(distw) + log(gdp_o) + log(gdp_d) + tdiff + heg_o + heg_d + curcol + comcur + comrelig + transition_legalchange + gatt_o + gatt_d + fta_wto + acp_to_eu + eu_to_acp + gsp_o_d + gsp_d_d + dummy_bothin + dummy_onein , data = total_dataset_dummies_experiment)
fit_2013_above <- lm(log(total_import) ~ contig + comlang_off + comlang_ethno + comcol + log(distw) + log(pop_o) + log(pop_d) + log(area_o) + log(area_d) + log(gdp_o) + log(gdp_d) + log(area_d) + tdiff + heg_o + heg_d + curcol + cursib + comcur + comrelig + transition_legalchange + gatt_o + gatt_d + fta_wto + acp_to_eu + eu_to_acp + gsp_o_d + gsp_d_d + dummy_2014 + dummy_2015 + dummy_bothin + dummy_onein , data = dataset_2013_above_final)
fit_2013_above_nozeros <- lm(log(total_import) ~ dummy2014 + dummy2015 + contig + comlang_off + comlang_ethno + comcol + log(distw) + log(pop_o) + log(pop_d) + log(area_o) + log(area_d) + log(gdp_o) + log(gdp_d) + tdiff + heg_o + heg_d + curcol + cursib + comcur + comrelig + transition_legalchange + gatt_o + gatt_d + fta_wto + acp_to_eu + eu_to_acp + gsp_o_d + gsp_d_d + dummy_bothin + dummy_onein , data = dataset_2013_above_nozeros)
# make linear models for data with and without zero export values

fit_total_dummies_experiment_ppml_log <- ppml(dependent_variable = "log_total_import", distance = "distw", additional_regressors = c("year","contig", "comlang_off", "comlang_ethno", "comcol", "log_gdp_o", "log_gdp_d", "tdiff", "heg_o", "heg_d", "curcol",  "comcur", "comrelig", "transition_legalchange", "gatt_o", "gatt_d", "fta_wto", "acp_to_eu", "eu_to_acp", "gsp_o_d", "gsp_d_d", "dummy_bothin", "dummy_onein"), data = total_dataset_dummies_experiment_ppml_log)
fit_total_dummies_experiment_ppml <- ppml(dependent_variable = "total_import", distance = "distw", additional_regressors = c("year","contig", "comlang_off", "comlang_ethno", "comcol", "log_gdp_o", "log_gdp_d", "tdiff", "heg_o", "heg_d", "curcol", "comcur", "comrelig", "transition_legalchange", "gatt_o", "gatt_d", "fta_wto", "acp_to_eu", "eu_to_acp", "gsp_o_d", "gsp_d_d", "dummy_bothin", "dummy_onein"), data = total_dataset_dummies_experiment_ppml)
fit_2013_above_nozeros_ppml <- ppml(dependent_variable = "total_import", distance = "distw", additional_regressors = c("dummy2014", "dummy2015", "contig", "comlang_off", "comlang_ethno", "comcol", "log_pop_o", "log_pop_d", "log_area_o", "log_area_d", "log_gdp_o", "log_gdp_d", "tdiff", "heg_o", "heg_d", "curcol", "cursib", "comcur", "comrelig", "transition_legalchange", "gatt_o", "gatt_d", "fta_wto", "acp_to_eu", "eu_to_acp", "gsp_o_d", "gsp_d_d", "dummy_bothin", "dummy_onein"), data = dataset_2013_above_nozeros_ppml)
fit_2013_above_ppml <- ppml(dependent_variable = "total_import", distance = "distw", additional_regressors = c("dummy2014", "dummy2015", "contig", "comlang_off", "comlang_ethno", "comcol", "log_pop_o", "log_pop_d", "log_area_o", "log_area_d", "log_gdp_o", "log_gdp_d", "tdiff", "heg_o", "heg_d", "curcol", "cursib", "comcur", "comrelig", "transition_legalchange", "gatt_o", "gatt_d", "fta_wto", "acp_to_eu", "eu_to_acp", "gsp_o_d", "gsp_d_d", "dummy_bothin", "dummy_onein"), data = dataset_2013_above_final_ppml)
# make a pseudo poisson maximum likelyhood model


total_dataset_dummies_average <- total_dataset_dummies
total_dataset_dummies_average$gdp_sum <- total_dataset_dummies_average$gdp_o + total_dataset_dummies_average$gdp_d
total_dataset_dummies_average$trade_flow <- total_dataset_dummies_average$trade_flow/2

stargazer(lsdv_total_dataset_dummies_experiment, fit_total_dummies_experiment, felm_total_dummies_experiment, type = "text", omit = c("iso3_d","iso3_o","year"), omit.labels = c("Importer FE?","Exporter FE?","Time dummies?"))



total_dataset_dummies_nozeros_panel <- total_dataset_dummies_nozeros
total_dataset_dummies_nozeros_panel$pair <- paste(total_dataset_dummies_nozeros$iso3_o,total_dataset_dummies_nozeros$iso3_d)
total_dataset_dummies_nozeros_panel <- pdata.frame(total_dataset_dummies_nozeros_panel, index=c("pair","year"), drop.index=FALSE, row.names=TRUE)

total_dataset_dummies_experiment_panel <- total_dataset_dummies_experiment
total_dataset_dummies_experiment_panel$pair <- paste(total_dataset_dummies_experiment$iso3_o,total_dataset_dummies_experiment$iso3_d)
total_dataset_dummies_experiment_panel <- pdata.frame(total_dataset_dummies_experiment_panel, index=c("pair","year"), drop.index=FALSE, row.names=TRUE)

total_dataset_dummies_panel <- total_dataset_dummies
total_dataset_dummies_panel$pair <- paste(total_dataset_dummies$iso3_o,total_dataset_dummies$iso3_d)
total_dataset_dummies_panel <- pdata.frame(total_dataset_dummies_panel, index=c("pair","year"), drop.index=FALSE, row.names=TRUE)

total_dataset_bothin_panel <- total_dataset_bothin_final
total_dataset_bothin_panel$pair <- paste(total_dataset_bothin_final$iso3_o,total_dataset_bothin_final$iso3_d)
total_dataset_bothin_panel <- pdata.frame(total_dataset_bothin_panel, index=c("pair","year"), drop.index=FALSE, row.names=TRUE)

total_dataset_onein_panel <- total_dataset_onein_final
total_dataset_onein_panel$pair <- paste(total_dataset_onein_final$iso3_o,total_dataset_onein_final$iso3_d)
total_dataset_onein_panel <- pdata.frame(total_dataset_onein_panel, index=c("pair","year"), drop.index=FALSE, row.names=TRUE)

total_dataset_panel <- total_dataset
total_dataset_panel$pair <- paste(total_dataset$iso3_o,total_dataset$iso3_d)
total_dataset_panel <- pdata.frame(total_dataset_panel, index=c("pair","year"), drop.index=FALSE, row.names=TRUE)
# pair identifiers and panel description




# LSDV - with exporter dummies, importer dummies and time dummies
stargazer(lsdv_2013, type="text", omit = c("iso3_d","iso3_o","year"), omit.labels = c("Importer FE?","Exporter FE?","Time dummies?"))


lsdv_total_dataset <- lm(formula = log(total_import) ~ contig + comlang_off + comlang_ethno +
                  comcol + log(distw) + log(gdp_o) + log(gdp_d) + tdiff +
                  heg_o + heg_d + curcol + cursib + comcur + comrelig + transition_legalchange +
                  gatt_o + gatt_d + fta_wto + acp_to_eu + eu_to_acp + gsp_o_d +
                  gsp_d_d + dummy_bothin + dummy_onein + factor(iso3_o) + factor(iso3_d) + factor(year),
                data = total_dataset)

lsdv_total_dataset_dummies <- lm(formula = log(total_import) ~ contig + comlang_off + comlang_ethno +
                           comcol + log(distw) + log(gdp_o) + log(gdp_d) + tdiff +
                           heg_o + heg_d + curcol + comcur + comrelig + transition_legalchange +
                           gatt_o + gatt_d + fta_wto + acp_to_eu + eu_to_acp + gsp_o_d +
                           gsp_d_d + dummy_bothin + dummy_onein + factor(iso3_o) + factor(iso3_d) + factor(year),
                         data = total_dataset_dummies)


lsdv_total_dataset_dummies_experiment <- lm(formula = log(total_import) ~ contig + comlang_off + comlang_ethno +
                                   comcol + log(distw) + log(gdp_o) + log(gdp_d) + tdiff +
                                   heg_o + heg_d + curcol + comcur + comrelig + transition_legalchange +
                                   gatt_o + gatt_d + fta_wto + acp_to_eu + eu_to_acp + gsp_o_d +
                                   gsp_d_d + dummy_bothin + dummy_onein + factor(iso3_o) + factor(iso3_d) + factor(year),
                                 data = total_dataset_dummies_experiment)


lsdv_total_dataset_dummies_nozeros <- lm(formula = log(total_import) ~ contig + comlang_off + comlang_ethno +
                                   comcol + log(distw) + log(gdp_o) + log(gdp_d) + tdiff +
                                   heg_o + heg_d + curcol + comcur + comrelig + transition_legalchange +
                                   gatt_o + gatt_d + fta_wto + acp_to_eu + eu_to_acp + gsp_o_d +
                                   gsp_d_d + dummy_bothin + dummy_onein + factor(iso3_o) + factor(iso3_d) + factor(year),
                                 data = total_dataset_dummies_nozeros)





# fixed effects - with pair effects and time dummies
stargazer(lsdv_2013, fixed_effects_2013_nozeros, type="text", omit = c("iso3_d","iso3_o","year"), omit.labels = c("Importer FE?","Exporter FE?","Time dummies?"))




fixed_effects_total_dummies <- plm(formula = log(total_import) ~ contig +
                                    comlang_off + comlang_ethno + comcol + log(distw) +
                                    + log(gdp_o) + log(gdp_d) +
                                    tdiff + heg_o + heg_d + curcol + cursib + comcur + comrelig +
                                    transition_legalchange + gatt_o + gatt_d + fta_wto + acp_to_eu +
                                    eu_to_acp + gsp_o_d + gsp_d_d + dummy_bothin + dummy_onein + factor(year),
                                  data = total_dataset_dummies_panel, index = c("pair", "year"), 
                                  model = "within")

fixed_effects_total_experiment <- plm(formula = log(total_import) ~ contig +
                                     comlang_off + comlang_ethno + comcol + log(distw) +
                                     + log(gdp_o) + log(gdp_d) +
                                     tdiff + heg_o + heg_d + curcol + cursib + comcur + comrelig +
                                     transition_legalchange + gatt_o + gatt_d + fta_wto + acp_to_eu +
                                     eu_to_acp + gsp_o_d + gsp_d_d + dummy_bothin + dummy_onein + factor(year),
                                   data = total_dataset_dummies_experiment_panel, index = c("pair", "year"), 
                                   model = "within")


# simple panel approach with time-varying dummies 
# this approach often not work (too high memory requirements for normal laptops)
experiment <- plm(log(total_import) ~  log(gdp_o) + log(gdp_d) + contig +
                    comlang_off + comlang_ethno + comcol + log(distw) + iso3_o:year + iso3_d:year, 
                  data =  dataset_2013_above_nozeros_ppml,
                  index = c("pair", "year"), 
                  model = "within")
summary(experiment)

# felm - extremely fast option for many dummies
felm_total_dummies <- felm(log(total_import) ~  log(gdp_o) + log(gdp_d) + contig +
                    comlang_off + comlang_ethno + comcol + log(distw) + tdiff + heg_o + heg_d + curcol + comcur + comrelig +
                    transition_legalchange + gatt_o + gatt_d + fta_wto + acp_to_eu +
                    eu_to_acp + gsp_o_d + gsp_d_d + dummy_bothin + dummy_onein | as.factor(pair) + iso3_o:year + iso3_d:year, data = total_dataset_dummies_panel)
summary(felm_total_dummies)


felm_total_dummies_experiment <- felm(log(total_import) ~  log(gdp_o) + log(gdp_d) + contig +
                             comlang_off + comlang_ethno + comcol + log(distw) + tdiff + heg_o + heg_d + curcol + comcur + comrelig +
                             transition_legalchange + gatt_o + gatt_d + fta_wto + acp_to_eu +
                             eu_to_acp + gsp_o_d + gsp_d_d + dummy_bothin + dummy_onein | as.factor(pair) + iso3_o:year + iso3_d:year, data = total_dataset_dummies_experiment_panel)

felm_total_dummies_nozeros <- felm(log(total_import) ~  log(gdp_o) + log(gdp_d) + contig +
                                        comlang_off + comlang_ethno + comcol + log(distw) + tdiff + heg_o + heg_d + curcol + comcur + comrelig +
                                        transition_legalchange + gatt_o + gatt_d + fta_wto + acp_to_eu +
                                        eu_to_acp + gsp_o_d + gsp_d_d + dummy_bothin + dummy_onein | as.factor(pair) + iso3_o:year + iso3_d:year, data = total_dataset_dummies_nozeros_panel)






total_dataset_dummies_experiment <- total_dataset_dummies
total_dataset_dummies_experiment$dummy_bothin[total_dataset_dummies$year <= 2013] <- 0
total_dataset_dummies_experiment$dummy_onein[total_dataset_dummies$year <= 2013] <- 0


total_dataset_dummies_nozeros$dummy_bothin[total_dataset_dummies_nozeros$year <= 2013] <- 0
total_dataset_dummies_nozeros$dummy_onein[total_dataset_dummies_nozeros$year <= 2013] <- 0






total_dataset_dummies_plot <- total_dataset_dummies
total_dataset_dummies_plot$total_import[total_dataset_dummies_plot$total_import == 1] <- 0
plot_normal_interval <- ggqqplot(log(total_dataset_dummies_plot$total_import), title = "Data vs normln distribuce")


plot_normal_interval <- ggplot(data = total_dataset_dummies_ppml, aes(sample = total_dataset_dummies_ppml$total_import))
plot_normal_interval + stat_qq() + stat_qq_line()




stargazer(lsdv_2013, fixed_effects_2013_nozeros, type="text")
stargazer(fixed_effects_total_experiment, type = "latex", omit = c("iso3_o", "iso3_d", "year","gsp_o_d", "gsp_d_d", "eu_to_acp", "acp_to_eu", "fta_wto", "gatt_d", "gatt_o", "transition_legalchange", "comrelig", "comcur", "cursib", "curcol", "heg_d", "heg_o", "tdiff", "comcol", "comlang_ethno", "comlang_off", "contig"))




RSS <- c(crossprod(fit_2013_above_ppml$residuals))
MSE_fit_2013_above_ppml <- RSS / length(fit_2013_above_ppml$residuals)
RMSE_fit_2013_above_ppml <- sqrt(MSE_fit_2013_above_ppml)
sig2_fit_2013_above_ppml <- RSS / fit_2013_above_ppml$residuals

RSS <- c(crossprod(fit_2013_above_nozeros$residuals))
MSE_fit_2013_above_nozeros <- RSS / length(fit_2013_above_nozeros$residuals)
RMSE_fit_2013_above_nozeros <- sqrt(MSE_fit_2013_above_nozeros)
sig2_fit_2013_above_nozeros <- RSS / fit_2013_above_nozeros$residuals

RSS <- c(crossprod(fit_2013_above_nozeros_ppml$residuals))
MSE_fit_2013_above_nozeros_ppml <- RSS / length(fit_2013_above_nozeros_ppml$residuals)
RMSE_fit_2013_above_nozeros_ppml <- sqrt(MSE_fit_2013_above_nozeros_ppml)
sig2_fit_2013_above_nozeros_ppml <- RSS / fit_2013_above_nozeros_ppml$residuals

RSS <- c(crossprod(fit_2013_above$residuals))
MSE_fit_2013_above <- RSS / length(fit_2013_above$residuals)
RMSE_fit_2013_above <- sqrt(MSE_fit_2013_above)
sig2_fit_2013_above <- RSS / fit_2013_above$residuals
# RSS = residual sum of squares, MSE = mean squared error, RMSE = rootMSE, sig2 = pearson estimated residual variance